==> turbovnc-1.2.3.tar.gz: turbovnc-1.2.3/win/vncviewer/res/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by vncviewer.rc
//
#define IDR_TRAY                        101
#define IDD_HELP                        101
#define ID_CONN_CTLESC                  102
#define IDR_TRAYMENU                    103
#define ID_CONN_ABOUT                   103
#define IDI_MAINICON                    104
#define ID_CONN_CTLDOWN                 104
#define IDC_DOTCURSOR                   105
#define ID_CONN_CTLUP                   105
#define IDB_VNCBITMAP                   106
#define ID_CONN_ALTDOWN                 106
#define IDD_GENERAL_OPTION              106
#define ID_CONN_ALTUP                   107
#define IDD_PARENT                      107
#define IDB_VNC32                       108
#define ID_CONN_CTLALTDEL               108
#define IDD_APP_ABOUT                   109
#define IDT_TRAYTIMER                   109
#define ID_FULLSCREEN                   110
#define ID_REQUEST_REFRESH              111
#define ID_REQUEST_LOSSLESS_REFRESH     112
#define ID_FULLSCREEN_NODIALOG          113
#define ID_CONN_ALTENTER                114
#define ID_DEFAULT_WINDOW_SIZE          115
#define ID_TOGGLE_GRAB                  116
#define IDD_SESSION_DLG                 135
#define IDD_SERVINFO_DLG                137
#define IDD_AUTH_DIALOG                 138
#define IDD_LOGIN_AUTH_DIALOG           139
#define IDD_OPTIONDIALOG                151
#define IDT_EMULATE3BUTTONSTIMER        152
#define ID_CONN_SAVE_AS                 153
#define IDC_NOCURSOR                    153
#define IDR_VERSION2                    154
#define IDB_BITMAP1                     158
#define ID_TOOLBAR                      159
#define ID_DISCONNECT                   160
#define IDD_DIALOG1                     163
#define IDD_FTBROWSE_DLG                217
#define IDD_FILETRANSFER_DLG            219
#define IDD_FILETRANSFER_ABOUT          233
#define IDI_FILEUP                      239
#define IDI_FILERELOAD                  241
#define IDC_SMALLDOT                    244
#define IDD_CONNECTING_DIALOG           245
#define ID_CONN_SENDKEYDOWN             300
#define ID_CONN_SENDKEYUP               301
#define IDC_HOSTNAME_EDIT               1000
#define IDC_DPYNUM_EDIT                 1001
#define IDC_BELLDEICONIFY               1002
#define IDC_SERVINFO_EDIT               1003
#define IDC_VIEWONLY                    1005
#define IDC_LOGIN_EDIT                  1008
#define IDC_PASSWD_EDIT                 1009
#define IDC_TAB                         1010
#define IDC_OPTIONBUTTON                1012
#define IDC_DBCHECK                     1013
#define IDC_RAWRADIO                    1018
#define IDC_CRECTRADIO                  1019
#define IDC_RRERADIO                    1020
#define IDC_RBSRADIO                    1021
#define IDC_CORRERADIO                  1022
#define IDC_HEXTILERADIO                1023
#define IDC_ZLIBRADIO                   1024
#define IDC_TIGHTRADIO                  1025
#define IDC_ZLIBHEXRADIO                1026
#define IDC_EMULATECHECK                1027
#define IDC_FULLSCREEN                  1028
#define IDC_DISABLECLIPBOARD            1029
#define IDC_SCALING                     1030
#define IDC_SCALE_NUM                   1031
#define IDC_SCALE_DEN                   1032
#define IDC_CSHAPE_DISABLE_RADIO        1033
#define IDC_QUALITYLEVEL                1034
#define IDC_COMPRESSLEVEL               1035
#define IDC_CSHAPE_ENABLE_RADIO         1036
#define IDC_CSHAPE_IGNORE_RADIO         1037
#define IDC_OK                          1044
#define IDC_LIST_MODE                   1047
#define IDC_CHECK_MESSAGE               1048
#define IDC_CHECK_TOOLBAR               1049
#define IDC_EDIT_AMOUNT_LIST            1050
#define IDC_BUTTON_CLEAR_LIST           1051
#define IDC_CHECK_LOG_FILE              1052
#define IDC_EDIT_LOG_FILE               1053
#define IDC_FTBROWSETREE                1054
#define IDC_FTBROWSECANCEL              1055
#define IDC_FTBROWSEOK                  1056
#define IDC_EDIT_LOG_LEVEL              1057
#define IDC_SHARED                      1059
#define IDC_SPIN1                       1060
#define IDC_SPIN2                       1061
#define IDC_SPIN3                       1062
#define IDC_SPIN4                       1063
#define IDC_ENCODING                    1065
#define IDC_SCALE_EDIT                  1069
#define IDC_DOTCURSOR_RADIO             1070
#define IDC_NOCURSOR_RADIO              1071
#define IDC_NORMALCURSOR_RADIO          1072
#define IDC_EDIT_HELP                   1076
#define IDC_STATIC_LEVEL                1078
#define IDC_STATIC_QUALITY              1079
#define IDC_UPLOAD                      1080
#define IDC_DOWNLOAD                    1081
#define IDC_CLIENTPATH                  1082
#define IDC_CLIENTBROWSE_BUT            1083
#define IDC_SERVERPATH                  1084
#define IDC_SERVERBROWSE_BUT            1085
#define IDC_FTCLIENTLIST                1086
#define IDC_FTSERVERLIST                1087
#define IDC_FTABOUT                     1088
#define IDC_FTCANCEL                    1089
#define IDC_EXIT                        1090
#define IDC_FTPROGRESS                  1091
#define IDC_FTBROWSEEDIT                1092
#define IDC_LOAD                        1093
#define IDC_SERVERRELOAD                1094
#define IDC_STATIC_TEXT_LEVEL           1096
#define IDC_STATIC_FAST                 1097
#define IDC_STATIC_BEST                 1098
#define IDC_STATIC_TEXT_QUALITY         1099
#define IDC_STATIC_QBEST                1100
#define IDC_STATIC_POOR                 1101
#define IDC_STATIC_ENCODING             1102
#define IDC_STATIC_SCALE                1103
#define IDC_STATIC_P                    1104
#define IDC_STATIC_SERVER               1105
#define IDC_STATIC_LIST                 1106
#define IDC_STATIC_LOG_LEVEL            1108
#define IDC_STATIC_PORT                 1109
#define IDC_STATIC_FORMAT               1110
#define IDC_STATIC_RESTRICTIONS         1111
#define IDC_STATIC_DISPLAY              1112
#define IDC_STATIC_MOUSE                1113
#define IDC_STATIC_MCURSOR              1114
#define IDC_STATIC_IOPTIONS             1115
#define IDC_STATIC_LOGGING              1116
#define IDC_STATIC_LCURSOR              1117
#define IDC_STATIC_LMODE                1118
#define IDC_STATIC_PICTURE              1119
#define IDC_FTCOPY                      1120
#define IDC_SMALLDOTCURSOR_RADIO        1121
#define IDC_VNCHOST                     1124
#define IDC_CONNECTING_STATIC           1125
#define IDC_STATUS_STATIC               1126
#define IDC_LOCAL_COMP_LABEL            1127
#define IDC_TVNC_SERV_LABEL             1128
#define IDC_FTSTATUS                    1130
#define IDC_BUTTON2                     1131
#define IDC_LISTEN_PORT                 1132
#define IDC_BUTTON3                     1133
#define IDC_SERVERUP                    1134
#define IDC_BUTTON4                     1135
#define IDC_CLIENTRELOAD                1136
#define IDC_BUTTON5                     1137
#define IDC_CLIENTUP                    1138
#define IDC_LOG_BROWSE                  1139
#define IDC_BUILDTIME                   1140
#define IDC_STATIC_URL                  1141
#define IDC_STATIC_VERSION              1143
#define IDC_STATIC_COPYRIGHTS           1144
#define IDC_STATIC_BASEDON              1145
#define IDC_STATIC_LOGO                 1146
#define IDC_STATIC_HOST                 1147
#define IDC_STATIC_LOGIN                1148
#define IDC_STATIC_PASSWD               1149
#define IDC_SPAN                        1151
#define IDC_STATIC_APPNAME              1152
#define IDC_STATIC_SUBSAMP              5000
#define IDC_STATIC_QUAL                 5001
#define IDC_STATIC_COMPRESS             5002
#define IDC_STATIC_SFAST                5003
#define IDC_STATIC_SBEST                5004
#define IDC_STATIC_SLEVEL               5005
#define IDC_STATIC_SPAN                 5006
#define ID_SESSION_SET_CRECT            32777
#define IDC_SUBSAMPLEVEL                32778
#define IDC_ALLOW_JPEG                  32779
#define ID_SESSION_SWAPMOUSE            32785
#define ID_CLOSEDAEMON                  40001
#define ID_SHOWWINDOW                   40004
#define ID_NEWCONN                      40006
#define IDD_FILETRANSFER                40010
#define IDS_NUMHELP                     33
#define IDS_HELP                        40101
#define IDS_HELP2                       40102
#define IDS_HELP3                       40103
#define IDS_HELP4                       40104
#define IDS_HELP5                       40105
#define IDS_HELP6                       40106
#define IDS_HELP7                       40107
#define IDS_HELP8                       40108
#define IDS_HELP9                       40109
#define IDS_HELP10                      40110
#define IDS_HELP11                      40111
#define IDS_HELP12                      40112
#define IDS_HELP13                      40113
#define IDS_HELP14                      40114
#define IDS_HELP15                      40115
#define IDS_HELP16                      40116
#define IDS_HELP17                      40117
#define IDS_HELP18                      40118
#define IDS_HELP19                      40119
#define IDS_HELP20                      40120
#define IDS_HELP21                      40121
#define IDS_HELP22                      40122
#define IDS_HELP23                      40123
#define IDS_HELP24                      40124
#define IDS_HELP25                      40125
#define IDS_HELP26                      40126
#define IDS_HELP27                      40127
#define IDS_HELP28                      40128
#define IDS_HELP29                      40129
#define IDS_HELP30                      40130
#define IDS_HELP31                      40131
#define IDS_HELP32                      40132
#define IDS_HELP33                      40133

// Next default values for new objects
//
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        246
#define _APS_NEXT_COMMAND_VALUE         40011
#define _APS_NEXT_CONTROL_VALUE         1150
#define _APS_NEXT_SYMED_VALUE           244
#endif
#endif

==> turbovnc-2.1.2.tar.gz: turbovnc-2.1.2/win/vncviewer/res/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by vncviewer.rc
//
#define IDR_TRAY                        101
#define IDD_HELP                        101
#define ID_CONN_CTLESC                  102
#define IDR_TRAYMENU                    103
#define ID_CONN_ABOUT                   103
#define IDI_MAINICON                    104
#define ID_CONN_CTLDOWN                 104
#define IDC_DOTCURSOR                   105
#define ID_CONN_CTLUP                   105
#define IDB_VNCBITMAP                   106
#define ID_CONN_ALTDOWN                 106
#define IDD_OPT_GLOBAL_TAB              106
#define ID_CONN_ALTUP                   107
#define IDD_PARENT                      107
#define IDB_VNC32                       108
#define ID_CONN_CTLALTDEL               108
#define IDD_APP_ABOUT                   109
#define IDT_TRAYTIMER                   109
#define ID_FULLSCREEN                   110
#define ID_REQUEST_REFRESH              111
#define ID_REQUEST_LOSSLESS_REFRESH     112
#define ID_FULLSCREEN_NODIALOG          113
#define ID_CONN_ALTENTER                114
#define ID_DEFAULT_WINDOW_SIZE          115
#define ID_TOGGLE_GRAB                  116
#define IDD_SESSION_DLG                 135
#define IDD_SERVINFO_DLG                137
#define IDD_AUTH_DIALOG                 138
#define IDD_LOGIN_AUTH_DIALOG           139
#define IDD_OPT_ENC_TAB                 151
#define IDT_EMULATE3BUTTONSTIMER        152
#define ID_CONN_SAVE_AS                 153
#define IDC_NOCURSOR                    153
#define IDR_VERSION2                    154
#define IDT_RESIZETIMER                 155
#define IDB_BITMAP1                     158
#define ID_TOOLBAR                      159
#define ID_DISCONNECT                   160
#define IDD_DIALOG1                     163
#define IDD_FTBROWSE_DLG                217
#define IDD_FILETRANSFER_DLG            219
#define IDD_FILETRANSFER_ABOUT          233
#define IDI_FILEUP                      239
#define IDI_FILERELOAD                  241
#define IDC_SMALLDOT                    244
#define IDD_CONNECTING_DIALOG           245
#define IDD_OPT_CONN_TAB                246
#define ID_CONN_SENDKEYDOWN             300
#define ID_CONN_SENDKEYUP               301
#define IDC_HOSTNAME_EDIT               1000
#define IDC_DPYNUM_EDIT                 1001
#define IDC_BELLDEICONIFY               1002
#define IDC_SERVINFO_EDIT               1003
#define IDC_VIEWONLY                    1005
#define IDC_LOGIN_EDIT                  1008
#define IDC_PASSWD_EDIT                 1009
#define IDC_TAB                         1010
#define IDC_OPTIONBUTTON                1012
#define IDC_RAWRADIO                    1018
#define IDC_CRECTRADIO                  1019
#define IDC_RRERADIO                    1020
#define IDC_RBSRADIO                    1021
#define IDC_CORRERADIO                  1022
#define IDC_HEXTILERADIO                1023
#define IDC_ZLIBRADIO                   1024
#define IDC_TIGHTRADIO                  1025
#define IDC_ZLIBHEXRADIO                1026
#define IDC_EMULATECHECK                1027
#define IDC_FULLSCREEN                  1028
#define IDC_DISABLECLIPBOARD            1029
#define IDC_SCALING                     1030
#define IDC_SCALE_NUM                   1031
#define IDC_SCALE_DEN                   1032
#define IDC_CSHAPE_DISABLE_RADIO        1033
#define IDC_QUALITYLEVEL                1034
#define IDC_COMPRESSLEVEL               1035
#define IDC_CSHAPE_ENABLE_RADIO         1036
#define IDC_CSHAPE_IGNORE_RADIO         1037
#define IDC_OK                          1044
#define IDC_LIST_MODE                   1047
#define IDC_CHECK_MESSAGE               1048
#define IDC_CHECK_TOOLBAR               1049
#define IDC_EDIT_AMOUNT_LIST            1050
#define IDC_BUTTON_CLEAR_LIST           1051
#define IDC_CHECK_LOG_FILE              1052
#define IDC_EDIT_LOG_FILE               1053
#define IDC_FTBROWSETREE                1054
#define IDC_FTBROWSECANCEL              1055
#define IDC_FTBROWSEOK                  1056
#define IDC_EDIT_LOG_LEVEL              1057
#define IDC_SHARED                      1059
#define IDC_SPIN1                       1060
#define IDC_SPIN2                       1061
#define IDC_SPIN3                       1062
#define IDC_SPIN4                       1063
#define IDC_ENCODING                    1065
#define IDC_DESKTOPSIZE_EDIT            1068
#define IDC_SCALE_EDIT                  1069
#define IDC_DOTCURSOR_RADIO             1070
#define IDC_NOCURSOR_RADIO              1071
#define IDC_NORMALCURSOR_RADIO          1072
#define IDC_EDIT_HELP                   1076
#define IDC_STATIC_LEVEL                1078
#define IDC_STATIC_QUALITY              1079
#define IDC_UPLOAD                      1080
#define IDC_DOWNLOAD                    1081
#define IDC_CLIENTPATH                  1082
#define IDC_CLIENTBROWSE_BUT            1083
#define IDC_SERVERPATH                  1084
#define IDC_SERVERBROWSE_BUT            1085
#define IDC_FTCLIENTLIST                1086
#define IDC_FTSERVERLIST                1087
#define IDC_FTABOUT                     1088
#define IDC_FTCANCEL                    1089
#define IDC_EXIT                        1090
#define IDC_FTPROGRESS                  1091
#define IDC_FTBROWSEEDIT                1092
#define IDC_LOAD                        1093
#define IDC_SERVERRELOAD                1094
#define IDC_STATIC_TEXT_LEVEL           1096
#define IDC_STATIC_FAST                 1097
#define IDC_STATIC_BEST                 1098
#define IDC_STATIC_TEXT_QUALITY         1099
#define IDC_STATIC_QBEST                1100
#define IDC_STATIC_POOR                 1101
#define IDC_STATIC_ENCODING             1102
#define IDC_STATIC_SCALE                1103
#define IDC_STATIC_P                    1104
#define IDC_STATIC_SERVER               1105
#define IDC_STATIC_LIST                 1106
#define IDC_STATIC_DESKTOPSIZE          1107
#define IDC_STATIC_LOG_LEVEL            1108
#define IDC_STATIC_PORT                 1109
#define IDC_STATIC_FORMAT               1110
#define IDC_STATIC_RESTRICTIONS         1111
#define IDC_STATIC_DISPLAY              1112
#define IDC_STATIC_MOUSE                1113
#define IDC_STATIC_MCURSOR              1114
#define IDC_STATIC_IOPTIONS             1115
#define IDC_STATIC_LOGGING              1116
#define IDC_STATIC_LCURSOR              1117
#define IDC_STATIC_LMODE                1118
#define IDC_STATIC_PICTURE              1119
#define IDC_FTCOPY                      1120
#define IDC_SMALLDOTCURSOR_RADIO        1121
#define IDC_VNCHOST                     1124
#define IDC_CONNECTING_STATIC           1125
#define IDC_STATUS_STATIC               1126
#define IDC_LOCAL_COMP_LABEL            1127
#define IDC_TVNC_SERV_LABEL             1128
#define IDC_FTSTATUS                    1130
#define IDC_BUTTON2                     1131
#define IDC_LISTEN_PORT                 1132
#define IDC_BUTTON3                     1133
#define IDC_SERVERUP                    1134
#define IDC_BUTTON4                     1135
#define IDC_CLIENTRELOAD                1136
#define IDC_BUTTON5                     1137
#define IDC_CLIENTUP                    1138
#define IDC_LOG_BROWSE                  1139
#define IDC_BUILDTIME                   1140
#define IDC_STATIC_URL                  1141
#define IDC_STATIC_VERSION              1143
#define IDC_STATIC_COPYRIGHTS           1144
#define IDC_STATIC_BASEDON              1145
#define IDC_STATIC_LOGO                 1146
#define IDC_STATIC_HOST                 1147
#define IDC_STATIC_LOGIN                1148
#define IDC_STATIC_PASSWD               1149
#define IDC_GRAB                        1150
#define IDC_SPAN                        1151
#define IDC_STATIC_APPNAME              1152
#define IDC_STATIC_SUBSAMP              5000
#define IDC_STATIC_QUAL                 5001
#define IDC_STATIC_COMPRESS             5002
#define IDC_STATIC_SFAST                5003
#define IDC_STATIC_SBEST                5004
#define IDC_STATIC_SLEVEL               5005
#define IDC_STATIC_SPAN                 5006
#define IDC_STATIC_GRAB                 5007
#define ID_SESSION_SET_CRECT            32777
#define IDC_SUBSAMPLEVEL                32778
#define IDC_ALLOW_JPEG                  32779
#define ID_SESSION_SWAPMOUSE            32785
#define IDC_INTERFRAME                  32786
#define ID_CLOSEDAEMON                  40001
#define ID_SHOWWINDOW                   40004
#define ID_NEWCONN                      40006
#define IDD_FILETRANSFER                40010
#define IDS_NUMHELP                     36
#define IDS_HELP                        40101
#define IDS_HELP2                       40102
#define IDS_HELP3                       40103
#define IDS_HELP4                       40104
#define IDS_HELP5                       40105
#define IDS_HELP6                       40106
#define IDS_HELP7                       40107
#define IDS_HELP8                       40108
#define IDS_HELP9                       40109
#define IDS_HELP10                      40110
#define IDS_HELP11                      40111
#define IDS_HELP12                      40112
#define IDS_HELP13                      40113
#define IDS_HELP14                      40114
#define IDS_HELP15                      40115
#define IDS_HELP16                      40116
#define IDS_HELP17                      40117
#define IDS_HELP18                      40118
#define IDS_HELP19                      40119
#define IDS_HELP20                      40120
#define IDS_HELP21                      40121
#define IDS_HELP22                      40122
#define IDS_HELP23                      40123
#define IDS_HELP24                      40124
#define IDS_HELP25                      40125
#define IDS_HELP26                      40126
#define IDS_HELP27                      40127
#define IDS_HELP28                      40128
#define IDS_HELP29                      40129
#define IDS_HELP30                      40130
#define IDS_HELP31                      40131
#define IDS_HELP32                      40132
#define IDS_HELP33                      40133
#define IDS_HELP34                      40134
#define IDS_HELP35                      40135
#define IDS_HELP36                      40136

// Next default values for new objects
//
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        247
#define _APS_NEXT_COMMAND_VALUE         40137
#define _APS_NEXT_CONTROL_VALUE         1153
#define _APS_NEXT_SYMED_VALUE           247
#endif
#endif
